@@ -24,10 +24,11 @@
 
 #include "cc-keyboard-manager.h"
 #include "keyboard-shortcuts.h"
-#include "wm-common.h"
 
+#include <gdk/gdk.h>
 #ifdef GDK_WINDOWING_X11
-#include <gdk/gdkx.h>
+#include <gdk/x11/gdkx.h>
+#include <X11/Xatom.h>
 #endif
 
 #define BINDINGS_SCHEMA       "org.gnome.settings-daemon.plugins.media-keys"
@@ -44,8 +45,6 @@ struct _CcKeyboardManager
   GHashTable         *kb_user_sections;
 
   GSettings          *binding_settings;
-
-  gpointer            wm_changed_id;
 };
 
 G_DEFINE_TYPE (CcKeyboardManager, cc_keyboard_manager, G_TYPE_OBJECT)
@@ -55,13 +54,14 @@ enum
   SHORTCUT_ADDED,
   SHORTCUT_CHANGED,
   SHORTCUT_REMOVED,
+  SHORTCUTS_LOADED,
   LAST_SIGNAL
 };
 
 static guint signals[LAST_SIGNAL] = { 0, };
 
 /*
- * Auxiliary methos
+ * Auxiliary methods
  */
 static void
 free_key_array (GPtrArray *keys)
@@ -263,6 +263,8 @@ add_shortcuts (CcKeyboardManager *self)
 
       can_continue = gtk_tree_model_iter_next (sections_model, &sections_iter);
     }
+
+  g_signal_emit (self, signals[SHORTCUTS_LOADED], 0);
 }
 
 static void
@@ -497,6 +499,166 @@ append_sections_from_gsettings (CcKeyboardManager *self)
   g_array_free (entries, TRUE);
 }
 
+#ifdef GDK_WINDOWING_X11
+static char *
+get_window_manager_property (GdkDisplay *display,
+                             Atom        atom,
+                             Window      window)
+{
+  Display *xdisplay;
+  Atom utf8_string;
+  int result;
+  Atom actual_type;
+  int actual_format;
+  unsigned long n_items;
+  unsigned long bytes_after;
+  unsigned char *prop;
+  char *value;
+
+  if (window == None)
+    return NULL;
+
+  xdisplay = gdk_x11_display_get_xdisplay (display);
+  utf8_string = XInternAtom (xdisplay, "UTF8_STRING", False);
+
+  gdk_x11_display_error_trap_push (display);
+
+  result = XGetWindowProperty (xdisplay,
+                               window,
+                               atom,
+                               0,
+                               G_MAXLONG,
+                               False,
+                               utf8_string,
+                               &actual_type,
+                               &actual_format,
+                               &n_items,
+                               &bytes_after,
+                               &prop);
+
+  gdk_x11_display_error_trap_pop_ignored (display);
+
+  if (result != Success ||
+      actual_type != utf8_string ||
+      actual_format != 8 ||
+      n_items == 0)
+    {
+      XFree (prop);
+      return NULL;
+    }
+
+  value = g_strndup ((const char *) prop, n_items);
+  XFree (prop);
+
+  if (!g_utf8_validate (value, -1, NULL))
+    {
+      g_free (value);
+      return NULL;
+    }
+
+  return value;
+}
+
+static Window
+get_wm_window (GdkDisplay *display)
+{
+  Display *xdisplay;
+  Atom wm_check;
+  int result;
+  Atom actual_type;
+  int actual_format;
+  unsigned long n_items;
+  unsigned long bytes_after;
+  unsigned char *prop;
+  Window wm_window;
+
+  xdisplay = gdk_x11_display_get_xdisplay (display);
+  wm_check = XInternAtom (xdisplay, "_NET_SUPPORTING_WM_CHECK", False);
+
+  gdk_x11_display_error_trap_push (display);
+
+  result = XGetWindowProperty (xdisplay,
+                               XDefaultRootWindow (xdisplay),
+                               wm_check,
+                               0,
+                               G_MAXLONG,
+                               False,
+                               XA_WINDOW,
+                               &actual_type,
+                               &actual_format,
+                               &n_items,
+                               &bytes_after,
+                               &prop);
+
+  gdk_x11_display_error_trap_pop_ignored (display);
+
+  if (result != Success ||
+      actual_type != XA_WINDOW ||
+      n_items == 0)
+    {
+      XFree (prop);
+      return None;
+    }
+
+  wm_window = *(Window *) prop;
+  XFree (prop);
+
+  return wm_window;
+}
+#endif
+
+static GStrv
+get_current_keybindings (void)
+{
+#ifdef GDK_WINDOWING_X11
+  GdkDisplay *display;
+  Display *xdisplay;
+  Atom keybindings_atom;
+  Window wm_window;
+  char *keybindings;
+  GStrv results;
+
+  display = gdk_display_get_default ();
+  if (!GDK_IS_X11_DISPLAY (display))
+    return NULL;
+
+  xdisplay = gdk_x11_display_get_xdisplay (display);
+  keybindings_atom = XInternAtom (xdisplay, "_GNOME_WM_KEYBINDINGS", False);
+
+  wm_window = get_wm_window (display);
+  keybindings = get_window_manager_property (display,
+                                             keybindings_atom,
+                                             wm_window);
+
+  if (keybindings != NULL)
+    {
+      GStrv p;
+
+      results = g_strsplit (keybindings, ",", -1);
+
+      for (p = results; p && *p; p++)
+        g_strstrip (*p);
+
+      g_free (keybindings);
+    }
+  else
+    {
+      Atom wm_atom;
+      char *wm_name;
+
+      wm_atom = XInternAtom (xdisplay, "_NET_WM_NAME", False);
+      wm_name = get_window_manager_property (display, wm_atom, wm_window);
+
+      results = g_new0 (char *, 2);
+      results[0] = wm_name ? wm_name : g_strdup ("Unknown");
+    }
+
+  return results;
+#else
+  return NULL;
+#endif
+}
+
 static void
 reload_sections (CcKeyboardManager *self)
 {
@@ -529,11 +691,9 @@ reload_sections (CcKeyboardManager *self)
                                                   (GDestroyNotify) free_key_array);
 
   /* Load WM keybindings */
-#ifdef GDK_WINDOWING_X11
-  if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
-    wm_keybindings = wm_common_get_current_keybindings ();
-  else
-#endif
+  wm_keybindings = get_current_keybindings ();
+
+  if (wm_keybindings == NULL)
     wm_keybindings = g_strdupv (default_wm_keybindings);
 
   loaded_files = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
@@ -580,13 +740,6 @@ reload_sections (CcKeyboardManager *self)
 /*
  * Callbacks
  */
-static void
-on_window_manager_change (const char        *wm_name,
-                          CcKeyboardManager *self)
-{
-  reload_sections (self);
-}
-
 static void
 cc_keyboard_manager_finalize (GObject *object)
 {
@@ -596,8 +749,7 @@ cc_keyboard_manager_finalize (GObject *object)
   g_clear_pointer (&self->kb_apps_sections, g_hash_table_destroy);
   g_clear_pointer (&self->kb_user_sections, g_hash_table_destroy);
   g_clear_object (&self->binding_settings);
-
-  g_clear_pointer (&self->wm_changed_id, wm_common_unregister_window_manager_change);
+  g_clear_object (&self->sections_store);
 
   G_OBJECT_CLASS (cc_keyboard_manager_parent_class)->finalize (object);
 }
@@ -670,6 +822,17 @@ cc_keyboard_manager_class_init (CcKeyboardManagerClass *klass)
                                             G_TYPE_NONE,
                                             1,
                                             CC_TYPE_KEYBOARD_ITEM);
+
+  /**
+   * CcKeyboardManager:shortcuts-loaded:
+   *
+   * Emitted after all shortcuts are loaded.
+   */
+  signals[SHORTCUTS_LOADED] = g_signal_new ("shortcuts-loaded",
+                                            CC_TYPE_KEYBOARD_MANAGER,
+                                            G_SIGNAL_RUN_FIRST,
+                                            0, NULL, NULL, NULL,
+                                            G_TYPE_NONE, 0);
 }
 
 static void
@@ -683,12 +846,6 @@ cc_keyboard_manager_init (CcKeyboardManager *self)
                                              G_TYPE_STRING,
                                              G_TYPE_STRING,
                                              G_TYPE_INT);
-
-#ifdef GDK_WINDOWING_X11
-  if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
-    self->wm_changed_id = wm_common_register_window_manager_change ((GFunc) on_window_manager_change,
-                                                                    self);
-#endif
 }
 
 
